@@ -106,7 +106,7 @@ function createComponentObject(model, parentView) {
       callVueFn('created', this);
     },
 
-    watch: _objectSpread({}, vuefile.SCRIPT && vuefile.SCRIPT.watch, {}, createWatches(model, parentView)),
+    watch: createWatches(model, parentView, vuefile.SCRIPT && vuefile.SCRIPT.watch),
     methods: _objectSpread({}, vuefile.SCRIPT && vuefile.SCRIPT.methods, {}, methods, {}, createMethods(model, parentView)),
     components: _objectSpread({}, createInstanceComponents(instanceComponents, parentView), {}, createClassComponents(classComponents, model, parentView), {}, createFullVueComponents(fullVueComponents)),
     computed: _objectSpread({}, vuefile.SCRIPT && vuefile.SCRIPT.computed, {}, aliasRefProps(model)),
@@ -140,7 +140,7 @@ function createComponentObject(model, parentView) {
 }
 
 function createDataMapping(model) {
-  return model.keys().filter(prop => !prop.startsWith('_') && !['events', 'template', 'components'].includes(prop)).reduce((result, prop) => {
+  return model.keys().filter(prop => !prop.startsWith('_') && !['events', 'template', 'components', 'layout', 'css', 'data', 'methods'].includes(prop)).reduce((result, prop) => {
     result[prop] = _.cloneDeep(model.get(prop)); // eslint-disable-line no-param-reassign
 
     return result;
@@ -148,7 +148,7 @@ function createDataMapping(model) {
 }
 
 function addModelListeners(model, vueModel) {
-  model.keys().filter(prop => !prop.startsWith('_') && !['v_model', 'components'].includes(prop)) // eslint-disable-next-line no-param-reassign
+  model.keys().filter(prop => !prop.startsWith('_') && !['v_model', 'components', 'layout', 'css', 'data', 'methods'].includes(prop)) // eslint-disable-next-line no-param-reassign
   .forEach(prop => model.on("change:".concat(prop), () => {
     if (_.isEqual(model.get(prop), vueModel[prop])) {
       return;
@@ -158,11 +158,16 @@ function addModelListeners(model, vueModel) {
   }));
 }
 
-function createWatches(model, parentView) {
-  return model.keys().filter(prop => !prop.startsWith('_') && !['events', 'template', 'components', 'layout'].includes(prop)).reduce((result, prop) => _objectSpread({}, result, {
+function createWatches(model, parentView, templateWatchers) {
+  return model.keys().filter(prop => !prop.startsWith('_') && !['events', 'template', 'components', 'layout', 'css', 'data', 'methods'].includes(prop)).reduce((result, prop) => _objectSpread({}, result, {
     [prop]: {
-      handler: value => {
+      handler(value) {
+        if (templateWatchers && templateWatchers[prop]) {
+          templateWatchers[prop].bind(this)(value);
+        }
         /* Don't send changes received from backend back */
+
+
         if (_.isEqual(value, model.get(prop))) {
           return;
         }
@@ -170,6 +175,7 @@ function createWatches(model, parentView) {
         model.set(prop, value === undefined ? null : _.cloneDeep(value));
         model.save_changes(model.callbacks(parentView));
       },
+
       deep: true
     }
   }), {});
